@@ -7,7 +7,7 @@ use DateTime::Format::Pg;
 use Rose::DB;
 our @ISA = qw(Rose::DB);
 
-our $VERSION = '0.55';
+our $VERSION = '0.57';
 
 our $Debug = 0;
 
@@ -46,9 +46,10 @@ sub init_date_handler
 }
 
 sub default_implicit_schema { 'public' }
-sub likes_lowercase_table_names   { 1 }
-sub likes_lowercase_schema_names  { 1 }
-sub likes_lowercase_catalog_names { 1 }
+sub likes_lowercase_table_names    { 1 }
+sub likes_lowercase_schema_names   { 1 }
+sub likes_lowercase_catalog_names  { 1 }
+sub likes_lowercase_sequence_names { 1 }
 
 sub supports_schema { 1 }
 
@@ -216,7 +217,7 @@ sub auto_sequence_name
 
 sub refine_dbi_column_info
 {
-  my($self, $col_info) = @_;
+  my($self, $col_info, $meta) = @_;
 
   # Save default value
   my $default = $col_info->{'COLUMN_DEF'};
@@ -226,7 +227,50 @@ sub refine_dbi_column_info
   # Set sequence name key, if present
   if(defined $default && $default =~ /^nextval\(\(?'((?:''|[^']+))'::\w+/)
   {
-    $col_info->{'rdbo_default_value_sequence_name'} = $1;
+    $col_info->{'rdbo_default_value_sequence_name'} = 
+      $self->likes_lowercase_sequence_names ? lc $1 : $1;
+
+    if($meta)
+    {
+      my $seq = $col_info->{'rdbo_default_value_sequence_name'};
+
+      my $implicit_schema = $self->default_implicit_schema;
+
+      # Strip off default implicit schema unless a schema is explicitly 
+      # specified in the RDBO metadata object.
+      if(defined $seq && defined $implicit_schema && !defined $meta->schema)
+      {
+        $seq =~ s/^$implicit_schema\.//;
+      }
+
+      $col_info->{'rdbo_default_value_sequence_name'} = $seq;
+
+      # Pg returns serial columns as integer or bigint
+      if($col_info->{'TYPE_NAME'} eq 'integer' ||
+         $col_info->{'TYPE_NAME'} eq 'bigint')
+      {
+        my $db = $meta->db;
+#$DB::single = 1;
+        my $auto_seq =
+          $db->auto_sequence_name(table  => $meta->table,
+                                  column => $col_info->{'COLUMN_NAME'});
+
+        # Use schema prefix on auto-generated name if necessary
+        if($seq =~ /^[^.]+\./)
+        {
+          my $schema = $meta->select_schema($db);
+          $auto_seq = "$schema.$auto_seq"  if($schema);
+        }
+
+        # If the sequence name
+        no warnings 'uninitialized';
+        if(lc $seq eq lc $auto_seq)
+        {
+          $col_info->{'TYPE_NAME'} =
+            $col_info->{'TYPE_NAME'} eq 'integer' ? 'serial' : 'bigserial';
+        }
+      }
+    }
   }
 
   # Pg has some odd names for types.  Convert them to standard forms.
@@ -239,11 +283,6 @@ sub refine_dbi_column_info
     $col_info->{'TYPE_NAME'} = 'bits';
   }
 
-  # Postgres 8.1 sometimes adds double quotes around the column name
-  if($col_info->{'COLUMN_NAME'} =~ /^"(.+)"$/)
-  {
-    $col_info->{'COLUMN_NAME'} = $1;
-  }
 
   # Pg does not populate COLUMN_SIZE correctly for bit fields, so
   # we have to extract the number of bits from pg_type.
